@@ -366,8 +366,9 @@ void build_widgets()
    cchar * batch_tags_tip = "Add/remove tags for multiple images";
    cchar * batch_rename_tags_tip = "Convert tag names for all images";
    cchar * batch_photo_DT_tip = "change or shift photo dates/times";
-   cchar * batch_change_mdata_tip = "Add/change/delete metadata for multiple images";
-   cchar * batch_report_mdata_tip = "Report metadata for multiple images";
+   cchar * batch_change_meta_tip = "Add/change/delete metadata for multiple images";
+   cchar * batch_report_meta_tip = "Report metadata for multiple images";
+   cchar * batch_meta_mover_tip = "move metadata between keys";
    cchar * batch_geotags_tip = "Add/revise geotags for multiple images";
    cchar * burn_DVD_tip = "Burn selected image files to DVD/BlueRay disc";
    cchar * export_filelist_tip = "Create a file of selected image files";
@@ -401,7 +402,6 @@ void build_widgets()
 
    //  help menu
    cchar * user_guide_tip = "Read the user guide";
-   cchar * recent_topics_tip = "User Guide - help topics for recent menus";
    cchar * video_tutorial_tip = "Fotoxx video tutorial on YouTube";
    cchar * all_edit_funcs_tip = "Overview of all edit functions";
    cchar * changelog_tip = "List updates by Fotoxx version";
@@ -612,8 +612,9 @@ void build_widgets()
    MENU(mBatch,    "Batch Tags", 0,              batch_tags_tip,            m_batch_tags, 0 );
    MENU(mBatch,    "Batch Rename Tags", 0,       batch_rename_tags_tip,     m_batch_rename_tags, 0 );
    MENU(mBatch,    "Batch Photo Date", 0,        batch_photo_DT_tip,        m_batch_photo_date_time, 0 );
-   MENU(mBatch,    "Batch Change Meta", 0,       batch_change_mdata_tip,    m_batch_change_metadata, 0 );
-   MENU(mBatch,    "Batch Report Meta", 0,       batch_report_mdata_tip,    m_batch_report_metadata, 0 );
+   MENU(mBatch,    "Batch Change Meta", 0,       batch_change_meta_tip,     m_batch_change_meta, 0 );
+   MENU(mBatch,    "Batch Report Meta", 0,       batch_report_meta_tip,     m_batch_report_meta, 0 );
+   MENU(mBatch,    "Batch Move Meta", 0,         batch_meta_mover_tip,      m_batch_meta_mover, 0 );
    MENU(mBatch,    "Batch Geotags", 0,           batch_geotags_tip,         m_batch_geotags, 0 );
    MENU(mBatch,    "Burn DVD/BlueRay", 0,        burn_DVD_tip,              m_burn_DVD, 0 );
    MENU(mBatch,    "Export File List", 0,        export_filelist_tip,       m_export_filelist, 0 );
@@ -647,7 +648,6 @@ void build_widgets()
 
    mHelp = create_popmenu();
    MENU(mHelp,    "User Guide", 0,               user_guide_tip,            m_help, 0 );
-   MENU(mHelp,    "Recent Topics", 0,            recent_topics_tip,         m_help, 0 );
    MENU(mHelp,    "Video Tutorial", 0,           video_tutorial_tip,        m_help, 0 );
    MENU(mHelp,    "All Edit Funcs", 0,           all_edit_funcs_tip,        m_help, 0 );
    MENU(mHelp,    "Command Params", 0,           command_params_tip,        m_help, 0 );
@@ -835,119 +835,109 @@ void build_widgets()
    
    //  build right-click popup menus --------------------------------------------
 
-   cchar    *menupopimage = "Popup Image";
    cchar    *menumeta1 = "View Meta";
    cchar    *menumeta1A = "View All Meta";
    cchar    *menumeta2 = "Edit Meta";
-   cchar    *menumeta3 = "Edit Any Meta";
    cchar    *menurename = "Rename";
-   cchar    *menupermissions = "Permissions";
+   cchar    *menudeltrash = "Delete/Trash";
    cchar    *menucopymove = "Copy/Move";
    cchar    *menucopytodesktop = "Copy to Desktop";
    cchar    *menucopytoclip = "Copy to Clipboard";
-   cchar    *menualbumaddselfiles = "Add Selected Files Here";
-   cchar    *menualbumaddcurrfile = "Add Current File Here";
-   cchar    *menuremovefromalbum = "Remove from Album";
-   cchar    *menucropimage = "Crop";
    cchar    *menurotateimage = "Rotate";
+   cchar    *menucropimage = "Crop";
+   cchar    *menuretouch = "Retouch";
    cchar    *menuresize = "Resize";
    cchar    *menuupright = "Upright";
+   cchar    *menusharpen = "Sharpen";
+   cchar    *menublur = "Blur";
+   cchar    *menudenoise = "Denoise";
    cchar    *menuvoodoo1 = "Voodoo 1";
    cchar    *menuvoodoo2 = "Voodoo 2";
-   cchar    *menuretouch = "Retouch";
    cchar    *menueditBD = "Edit Dist";
    cchar    *menuflattenBD = "Flatten Dist";
+   cchar    *menulocalcon = "Local Contrast";
    cchar    *menugradients = "Gradients";
-   cchar    *menuselect = "Select Area";
-   cchar    *menunetzoom = "Show on Map";
-   cchar    *menudeltrash = "Delete/Trash";
+   cchar    *menusaturation = "Saturation";
    cchar    *menuopenRT = "Raw Therapee";
    cchar    *menuopenDT = "Darktable";
    cchar    *menumpoextract = "Extract .MPO files";
    cchar    *menuthumbframe = "Thumbnail Frame";
+   cchar    *menupopimage = "Popup Image";
+   cchar    *menualbumaddselfiles = "Add Selected Files Here";
+   cchar    *menualbumaddcurrfile = "Add Current File Here";
+   cchar    *menuremovefromalbum = "Remove from Album";
 
    popmenu_image = create_popmenu();                                             //  popup menu for image files
-   add_popmenu_item(popmenu_image,menumeta1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_image,menumeta1A,popup_menufunc,"view all metadata");
-   add_popmenu_item(popmenu_image,menumeta2,popup_menufunc,"edit metadata");
-   add_popmenu_item(popmenu_image,menumeta3,popup_menufunc,"edit any metadata");
+   add_popmenu_item(popmenu_image,menumeta1,popup_menufunc,"view meta");
+   add_popmenu_item(popmenu_image,menumeta1A,popup_menufunc,"view all meta");
+   add_popmenu_item(popmenu_image,menumeta2,popup_menufunc,"edit meta");
    add_popmenu_item(popmenu_image,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_image,menupermissions,popup_menufunc,"permissions");
+   add_popmenu_item(popmenu_image,menudeltrash,popup_menufunc,"delete/trash");
    add_popmenu_item(popmenu_image,menucopymove,popup_menufunc,"copymove");
    add_popmenu_item(popmenu_image,menucopytodesktop,popup_menufunc,"copytodesktop");
    add_popmenu_item(popmenu_image,menucopytoclip,popup_menufunc,"copytoclip");
-   add_popmenu_item(popmenu_image,menuupright,popup_menufunc,"upright");
    add_popmenu_item(popmenu_image,menurotateimage,popup_menufunc,"rotate");
    add_popmenu_item(popmenu_image,menucropimage,popup_menufunc,"crop");
-   add_popmenu_item(popmenu_image,menuresize,popup_menufunc,"resize");
    add_popmenu_item(popmenu_image,menuretouch,popup_menufunc,"retouch");
+   add_popmenu_item(popmenu_image,menuresize,popup_menufunc,"resize");
+   add_popmenu_item(popmenu_image,menuupright,popup_menufunc,"upright");
+   add_popmenu_item(popmenu_image,menusharpen,popup_menufunc,"sharpen");
+   add_popmenu_item(popmenu_image,menublur,popup_menufunc,"blur");
+   add_popmenu_item(popmenu_image,menudenoise,popup_menufunc,"denoise");
    add_popmenu_item(popmenu_image,menuvoodoo1,popup_menufunc,"voodoo1");
    add_popmenu_item(popmenu_image,menuvoodoo2,popup_menufunc,"voodoo2");
    add_popmenu_item(popmenu_image,menueditBD,popup_menufunc,"edit dist");
    add_popmenu_item(popmenu_image,menuflattenBD,popup_menufunc,"flatten dist");
+   add_popmenu_item(popmenu_image,menulocalcon,popup_menufunc,"local contrast");
    add_popmenu_item(popmenu_image,menugradients,popup_menufunc,"gradients");
-   add_popmenu_item(popmenu_image,menuselect,popup_menufunc,"select");
-   add_popmenu_item(popmenu_image,menunetzoom,popup_menufunc,"netmap_zoomin");
-   add_popmenu_item(popmenu_image,menudeltrash,popup_menufunc,"delete/trash");
+   add_popmenu_item(popmenu_image,menusaturation,popup_menufunc,"saturation");
 
    popmenu_raw = create_popmenu();                                               //  popup menu for RAW files
    add_popmenu_item(popmenu_raw,menuopenRT,m_rawtherapee,0);
    add_popmenu_item(popmenu_raw,menuopenDT,m_darktable,0);
-   add_popmenu_item(popmenu_raw,menumeta1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_raw,menumeta1A,popup_menufunc,"view all metadata");
-   add_popmenu_item(popmenu_raw,menumeta2,popup_menufunc,"edit metadata");
+   add_popmenu_item(popmenu_raw,menumeta1,popup_menufunc,"view meta");
+   add_popmenu_item(popmenu_raw,menumeta1A,popup_menufunc,"view all meta");
+   add_popmenu_item(popmenu_raw,menumeta2,popup_menufunc,"edit meta");
    add_popmenu_item(popmenu_raw,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_raw,menupermissions,popup_menufunc,"permissions");
-   add_popmenu_item(popmenu_raw,menucopymove,popup_menufunc,"copymove");
-   add_popmenu_item(popmenu_raw,menucopytodesktop,popup_menufunc,"copytodesktop");
-   add_popmenu_item(popmenu_raw,menunetzoom,popup_menufunc,"netmap_zoomin");
    add_popmenu_item(popmenu_raw,menudeltrash,popup_menufunc,"delete/trash");
+   add_popmenu_item(popmenu_raw,menucopymove,popup_menufunc,"copymove");
 
    popmenu_mpo = create_popmenu();                                               //  popup menu for .MPO files
    add_popmenu_item(popmenu_mpo,menumpoextract,m_extract_mpo,0);
-   add_popmenu_item(popmenu_mpo,menumeta1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_mpo,menumeta1A,popup_menufunc,"view all metadata");
-   add_popmenu_item(popmenu_mpo,menumeta2,popup_menufunc,"edit metadata");
+   add_popmenu_item(popmenu_mpo,menumeta1,popup_menufunc,"view meta");
+   add_popmenu_item(popmenu_mpo,menumeta1A,popup_menufunc,"view all meta");
+   add_popmenu_item(popmenu_mpo,menumeta2,popup_menufunc,"edit meta");
    add_popmenu_item(popmenu_mpo,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_mpo,menupermissions,popup_menufunc,"permissions");
-   add_popmenu_item(popmenu_mpo,menucopymove,popup_menufunc,"copymove");
-   add_popmenu_item(popmenu_mpo,menucopytodesktop,popup_menufunc,"copytodesktop");
-   add_popmenu_item(popmenu_mpo,menunetzoom,popup_menufunc,"netmap_zoomin");
    add_popmenu_item(popmenu_mpo,menudeltrash,popup_menufunc,"delete/trash");
+   add_popmenu_item(popmenu_mpo,menucopymove,popup_menufunc,"copymove");
 
    popmenu_video = create_popmenu();                                             //  popup menu for VIDEO files
-   add_popmenu_item(popmenu_video,menumeta1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_video,menumeta1A,popup_menufunc,"view all metadata");
-   add_popmenu_item(popmenu_video,menumeta2,popup_menufunc,"edit metadata");
+   add_popmenu_item(popmenu_video,menumeta1,popup_menufunc,"view meta");
+   add_popmenu_item(popmenu_video,menumeta1A,popup_menufunc,"view all meta");
+   add_popmenu_item(popmenu_video,menumeta2,popup_menufunc,"edit meta");
    add_popmenu_item(popmenu_video,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_video,menupermissions,popup_menufunc,"permissions");
+   add_popmenu_item(popmenu_video,menudeltrash,popup_menufunc,"delete/trash");
    add_popmenu_item(popmenu_video,menucopymove,popup_menufunc,"copymove");
    add_popmenu_item(popmenu_video,menucopytodesktop,popup_menufunc,"copytodesktop");
-   add_popmenu_item(popmenu_video,menunetzoom,popup_menufunc,"netmap_zoomin");
    add_popmenu_item(popmenu_video,menuthumbframe,popup_menufunc,"thumbnail_frame");
-   add_popmenu_item(popmenu_video,menudeltrash,popup_menufunc,"delete/trash");
 
    popmenu_thumb = create_popmenu();                                             //  gallery thumbnail popup menu
    add_popmenu_item(popmenu_thumb,menupopimage,popup_menufunc,"popimage");
-   add_popmenu_item(popmenu_thumb,menumeta1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_thumb,menumeta1A,popup_menufunc,"view all metadata");
-   add_popmenu_item(popmenu_thumb,menumeta2,popup_menufunc,"edit metadata");
-   add_popmenu_item(popmenu_thumb,menumeta3,popup_menufunc,"edit any metadata");
+   add_popmenu_item(popmenu_thumb,menumeta1,popup_menufunc,"view meta");
+   add_popmenu_item(popmenu_thumb,menumeta1A,popup_menufunc,"view all meta");
+   add_popmenu_item(popmenu_thumb,menumeta2,popup_menufunc,"edit meta");
    add_popmenu_item(popmenu_thumb,menurename,popup_menufunc,"rename");
-   add_popmenu_item(popmenu_thumb,menupermissions,popup_menufunc,"permissions");
+   add_popmenu_item(popmenu_thumb,menudeltrash,popup_menufunc,"delete/trash");
    add_popmenu_item(popmenu_thumb,menucopymove,popup_menufunc,"copymove");
    add_popmenu_item(popmenu_thumb,menucopytodesktop,popup_menufunc,"copytodesktop");
    add_popmenu_item(popmenu_thumb,menucopytoclip,popup_menufunc,"copytoclip");
    add_popmenu_item(popmenu_thumb,menuupright,popup_menufunc,"upright");
-   add_popmenu_item(popmenu_thumb,menunetzoom,popup_menufunc,"netmap_zoomin");
-   add_popmenu_item(popmenu_thumb,menudeltrash,popup_menufunc,"delete/trash");
 
    popmenu_album = create_popmenu();                                             //  album thumbnail popup menu
    add_popmenu_item(popmenu_album,menupopimage,popup_menufunc,"popimage");
-   add_popmenu_item(popmenu_album,menumeta1,popup_menufunc,"view metadata");
-   add_popmenu_item(popmenu_album,menumeta1A,popup_menufunc,"view all metadata");
-   add_popmenu_item(popmenu_album,menumeta2,popup_menufunc,"edit metadata");
-   add_popmenu_item(popmenu_album,menumeta3,popup_menufunc,"edit any metadata");
+   add_popmenu_item(popmenu_album,menumeta1,popup_menufunc,"view meta");
+   add_popmenu_item(popmenu_album,menumeta1A,popup_menufunc,"view all meta");
+   add_popmenu_item(popmenu_album,menumeta2,popup_menufunc,"edit meta");
    add_popmenu_item(popmenu_album,menucopytodesktop,popup_menufunc,"copytodesktop");
    add_popmenu_item(popmenu_album,menucopytoclip,popup_menufunc,"copytoclip");
    add_popmenu_item(popmenu_album,menualbumaddselfiles,popup_menufunc,"albumaddselfiles");
@@ -962,35 +952,34 @@ void build_widgets()
 
 void popup_menufunc(GtkWidget *, cchar *menu)
 {
-   if (strmatch(menu,"popimage")) gallery_popimage();                            //  funcs for main and gallery windows
-   if (strmatch(menu,"upright")) m_upright(0,0);
-   if (strmatch(menu,"view metadata")) meta_view(1);
-   if (strmatch(menu,"view all metadata")) meta_view(2);
-   if (strmatch(menu,"edit metadata")) m_meta_edit_main(0,0);                    //  these use clicked_file if defined,
-   if (strmatch(menu,"edit any metadata")) m_meta_edit_any(0,0);                 //    else they use curr_file.
+   if (strmatch(menu,"view meta")) meta_view(1);
+   if (strmatch(menu,"view all meta")) meta_view(2);
+   if (strmatch(menu,"edit meta")) m_meta_edit_main(0,0);
    if (strmatch(menu,"rename")) m_rename(0,0);
-   if (strmatch(menu,"permissions")) m_permissions(0,0); 
+   if (strmatch(menu,"delete/trash")) m_delete_trash(0,0);
    if (strmatch(menu,"copymove")) m_copy_move(0,0);
    if (strmatch(menu,"copytodesktop")) m_copyto_desktop(0,0);
-   if (strmatch(menu,"delete/trash")) m_delete_trash(0,0);
-   if (strmatch(menu,"netmap_zoomin")) m_netmap_zoomin(0,0);
    if (strmatch(menu,"copytoclip")) m_copyto_clip(0,0);
-
-   if (strmatch(menu,"removefromalbum")) album_remove_file(clicked_posn);        //  funcs for album gallery depend
-   if (strmatch(menu,"albumaddselfiles")) album_add_selfiles(2);                 //    on 'clicked_posn' being set
-   if (strmatch(menu,"albumaddcurrfile")) album_add_currfile(2);
-
-   if (strmatch(menu,"rotate")) m_rotate(0,0);                                   //  functions using curr_file only
-   if (strmatch(menu,"crop")) m_crop(0,0);                                       //  (not for gallery/thumbnail click)
-   if (strmatch(menu,"resize")) m_resize(0,0);
+   if (strmatch(menu,"rotate")) m_rotate(0,0);
+   if (strmatch(menu,"crop")) m_crop(0,0);
    if (strmatch(menu,"retouch")) m_retouch(0,0);
+   if (strmatch(menu,"resize")) m_resize(0,0);
+   if (strmatch(menu,"upright")) m_upright(0,0);
+   if (strmatch(menu,"sharpen")) m_sharpen(0,0);
+   if (strmatch(menu,"blur")) m_blur(0,0);
+   if (strmatch(menu,"denoise")) m_denoise(0,0);
    if (strmatch(menu,"voodoo1")) m_voodoo1(0,0);
    if (strmatch(menu,"voodoo2")) m_voodoo2(0,0);
    if (strmatch(menu,"edit dist")) m_editBD(0,0);
    if (strmatch(menu,"flatten dist")) m_flattenBD(0,0);
+   if (strmatch(menu,"local contrast")) m_localcon(0,0);
    if (strmatch(menu,"gradients")) m_gradients(0,0);
-   if (strmatch(menu,"select")) m_select_area(0,0);
+   if (strmatch(menu,"saturation")) m_saturation(0,0);
    if (strmatch(menu,"thumbnail_frame")) m_thumbframe(0,0);
+   if (strmatch(menu,"popimage")) gallery_popimage();
+   if (strmatch(menu,"albumaddselfiles")) album_add_selfiles(2);
+   if (strmatch(menu,"albumaddcurrfile")) album_add_currfile(2);
+   if (strmatch(menu,"removefromalbum")) album_remove_file(clicked_posn);
 
    return;
 }
@@ -1214,14 +1203,14 @@ void m_custom_menu(GtkWidget *, cchar *)
    cchar       *menutran;
    int         ii, jj, Nm;
    
-   push_help_topic("custom menu");
+   F1_help_topic = "custom menu";
    
    Plog(2,"m_custom_menu \n");
 
    popmenu = create_popmenu();                                                   //  create popup menu
 
    snprintf(menufile,200,"%s/custom_menu",get_zhomedir());
-   Nm = readfile(menufile,menulist);
+   Nm = zreadfile(menufile,menulist);
    
    for (ii = 0; ii < Nm; ii++) 
    {
@@ -1243,7 +1232,7 @@ void m_custom_menu(GtkWidget *, cchar *)
 
    popup_menu(Mwin,popmenu);                                                     //  show popup menu
    
-   if (menulist) readfile_free(menulist);
+   if (menulist) zreadfile_free(menulist);
    return;
 }
 
@@ -1264,7 +1253,7 @@ void custom_menu_func(GtkWidget *, cchar *menu)
 
 void custom_menu_edit(GtkWidget *, cchar *)                                      //  edit the custom menu file
 {
-   push_help_topic("custom menu");
+   F1_help_topic = "custom menu";
 
    zshell(0,"xdg-open %s/custom_menu",get_zhomedir());
    return;
